@@ -14,13 +14,24 @@ import os
 __all__ = ['ValueBag']
  
 class ValueBag(dict):
-    def __init__(self, d = {}):
+    def __init__(self, d = {}, auto_create = True, empty_string = None):
         super(ValueBag, self).__init__()
         
         #assert parent == None or isinstance(parent, ValueBag)  
         #self.__dict__['__parent'] = parent 
+        self.__dict__['__auto_create'] = auto_create
+        self.__dict__['__empty_string'] = empty_string
         
         self.update(d)
+
+    def __str__(self):
+        if len(self) or self.__dict__['__empty_string'] is None:
+            return super(ValueBag, self).__str__()
+
+        return self.__dict__['__empty_string']
+
+    def __unicode__(self):
+        return str(self)
         
     def __setattr__(self, name, value):
         if name.startswith('__'):
@@ -65,7 +76,7 @@ class ValueBag(dict):
         if self.has_key(name):
             return self.get(name)
         
-        if not name.startswith('__'):
+        if not name.startswith('__') and self.__dict__['__auto_create']:
             setattr(self, name, {})
         return super(ValueBag, self).__getitem__(name)
     
